/////////////////////////////////////////////////////////
#ifndef _CALIBOOLEAN_H
#define _CALIBOOLEAN_H
/////////////////////////////////////////////////////////

enum Boolean
{ False = 0, True = 1, Notknown };
#endif
